import React from 'react';
import {Admin, Resource} from 'react-admin';
import CustomLayout from "./modules/common/layout/CustomLayout";
import AuthProvider from './modules/common/authentication/AuthProvider';
import DataProvider from './data/DataProvider';
import CustomRoutes from './modules/common/CustomRoutes';

import rootReducer from './reducers/Index'
import LoginPage from './modules/common/authentication/LoginPage';
import {createMuiTheme} from '@material-ui/core/styles'
import blueGrey from '@material-ui/core/colors/blueGrey';
import englishMessages from './i18n/en';

const i18nProvider = locale => {
    return englishMessages;
};

const theme = createMuiTheme({
    palette: {
        primary: blueGrey,
    },});

const App = (props) => {
    return (
        <Admin
            theme={theme}
            dataProvider={DataProvider()}
            appLayout={CustomLayout}
            authProvider={AuthProvider}
            customReducers={{rootReducer}}
            customRoutes={CustomRoutes}
            loginPage={LoginPage}
            locale="en"
            i18nProvider={i18nProvider}
        >
            {/** Here goes all the resources from you're application **/}
        </Admin>
    );
};

export default App;
