import React, { Component } from 'react';
import CustomMenu from './CustomMenu';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { withStyles} from '@material-ui/core/styles';
import {
    Notification,
    Sidebar,
    setSidebarVisibility,
} from 'react-admin';
import CustomAppBar from "./CustomAppBar";

const styles = theme => ({
    root: {
        display: 'flex',
        flexDirection: 'column',
        zIndex: 1,
        minHeight: '100vh',
        backgroundColor: theme.palette.background.default,
        position: 'relative',
    },
    appFrame: {
        display: 'flex',
        flexDirection: 'column',
        overflowX: 'auto',
    },
    contentWithSidebar: {
        display: 'flex',
        flexGrow: 1,
    },
    content: {
        display: 'flex',
        flexDirection: 'column',
        flexGrow: 2,
        padding: theme.spacing.unit * 3,
    },
});

class CustomLayout extends Component {
    componentWillMount() {
        this.props.setSidebarVisibility(false);
    }

    render() {
        const {
            children,
            classes,
            title,
        } = this.props;
        return (
            <div className={classes.root}>
                <div className={classes.appFrame}>
                    <CustomAppBar title={title}/>
                    <main className={classes.contentWithSidebar}>
                        <Sidebar style={{borderRight:'1px solid #EEE', height:'900px', backgroundColor:'#fff'}}>
                            <CustomMenu/>
                        </Sidebar>
                        <div className={classes.content}>
                            {children}
                        </div>
                    </main>
                    <Notification />
                </div>
            </div>
        );
    }
}

CustomLayout.propTypes = {
    children: PropTypes.oneOfType([PropTypes.func, PropTypes.node]),
    dashboard: PropTypes.oneOfType([
        PropTypes.func,
        PropTypes.string,
    ]),
    isLoading: PropTypes.bool.isRequired,
    setSidebarVisibility: PropTypes.func.isRequired,
    title: PropTypes.string.isRequired,
};

const mapStateToProps = state => ({ isLoading: state.admin.loading > 0 });

export default connect(mapStateToProps, { setSidebarVisibility })(withStyles(styles)(CustomLayout));